@@ -2,6 +2,7 @@
 # Copyright © 2008 Nicolas Kandel
 # Copyright © 2008 Pascal Halter
 # Copyright © 2008-2017 Guillaume Ayoub
+# Copyright © 2017-2019 Unrud <unrud@outlook.com>
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,10 +29,22 @@ import os
 EXAMPLES_FOLDER = os.path.join(os.path.dirname(__file__), "static")
 
 
+def get_file_path(file_name):
+    return os.path.join(EXAMPLES_FOLDER, file_name)
+
+
 def get_file_content(file_name):
     try:
-        with open(os.path.join(EXAMPLES_FOLDER, file_name),
-                  encoding="utf-8") as fd:
+        with open(get_file_path(file_name), encoding="utf-8") as fd:
             return fd.read()
     except IOError:
         print("Couldn't open the file %s" % file_name)
+
+
+def configuration_to_dict(configuration):
+    """Convert configuration to a dict with raw values."""
+    return {section: {option: configuration.get_raw(section, option)
+                      for option in configuration.options(section)
+                      if not option.startswith("_")}
+            for section in configuration.sections()
+            if not section.startswith("_")}
